==> lighthouse-1.1.6.tgz: package/lighthouse-core/test/gather/gatherers/viewport-test.js <==
/**
 * Copyright 2016 Google Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
'use strict';

/* eslint-env mocha */

const ViewportGather = require('../../../gather/gatherers/viewport');
const assert = require('assert');
let viewportGather;

describe('Viewport gatherer', () => {
  // Reset the Gatherer before each test.
  beforeEach(() => {
    viewportGather = new ViewportGather();
  });

  it('returns an artifact', () => {
    return viewportGather.afterPass({
      driver: {
        querySelector() {
          return Promise.resolve({
            getAttribute: () => 'width=device-width'
          });
        }
      }
    }).then(_ => {
      assert.ok(typeof viewportGather.artifact === 'string');
      assert.ok(/width=/gim.test(viewportGather.artifact));
    });
  });

  it('handles driver failure', () => {
    return viewportGather.afterPass({
      driver: {
        querySelector() {
          return Promise.reject('such a fail');
        }
      }
    }).then(_ => {
      assert.equal(viewportGather.artifact, -1);
    });
  });
});

==> lighthouse-1.3.0.tgz: package/lighthouse-core/test/gather/gatherers/viewport-test.js <==
/**
 * Copyright 2016 Google Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
'use strict';

/* eslint-env mocha */

const ViewportGather = require('../../../gather/gatherers/viewport');
const assert = require('assert');
let viewportGather;

describe('Viewport gatherer', () => {
  // Reset the Gatherer before each test.
  beforeEach(() => {
    viewportGather = new ViewportGather();
  });

  it('returns an artifact', () => {
    return viewportGather.afterPass({
      driver: {
        querySelector() {
          return Promise.resolve({
            getAttribute: () => 'width=device-width'
          });
        }
      }
    }).then(artifact => {
      assert.ok(typeof artifact === 'string');
      assert.ok(/width=/gim.test(artifact));
    });
  });

  it('handles driver failure', () => {
    return viewportGather.afterPass({
      driver: {
        querySelector() {
          return Promise.reject('such a fail');
        }
      }
    }).then(artifact => {
      assert.equal(artifact, -1);
    });
  });
});
